##############################
DemandSideManagementBETA class
##############################

.. |br| raw:: html

   <br />

A DemandSideManagementBETA component initializes one source and several storage components.

**DemandSideManagementBETA class description:**

.. automodule:: DSM
.. autoclass:: DemandSideManagementBETA 
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: DemandSideManagementBETA 
   :parts: 1

|

**DSMModel class description:**

.. autoclass:: DSMModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: DSMModel
   :parts: 1

